@@ -81,16 +81,12 @@ function _config_manila_apache_wsgi {
     " -i $manila_api_apache_conf
 }
 
-# configure_default_backends - configures default Manila backends with generic driver.
-function configure_default_backends {
-    # Configure two default backends with generic drivers onboard
-    for group_name in $MANILA_BACKEND1_CONFIG_GROUP_NAME $MANILA_BACKEND2_CONFIG_GROUP_NAME; do
+# configure_backends - Configures backends enabled by MANILA_ENABLED_BACKENDS
+function configure_backends {
+    # Configure MANILA_ENABLED_BACKENDS backends
+    for group_name in $(echo $MANILA_ENABLED_BACKENDS | sed "s/,/ /g"); do
         iniset $MANILA_CONF $group_name share_driver $SHARE_DRIVER
-        if [ "$MANILA_BACKEND1_CONFIG_GROUP_NAME" == "$group_name" ]; then
-            iniset $MANILA_CONF $group_name share_backend_name $MANILA_SHARE_BACKEND1_NAME
-        else
-            iniset $MANILA_CONF $group_name share_backend_name $MANILA_SHARE_BACKEND2_NAME
-        fi
+        iniset $MANILA_CONF $group_name share_backend_name ${group_name^^}
         iniset $MANILA_CONF $group_name path_to_public_key $MANILA_PATH_TO_PUBLIC_KEY
         iniset $MANILA_CONF $group_name path_to_private_key $MANILA_PATH_TO_PRIVATE_KEY
         iniset $MANILA_CONF $group_name service_image_name $MANILA_SERVICE_IMAGE_NAME
@@ -270,17 +266,13 @@ function configure_manila {
     if is_service_enabled glance; then
         configure_keystone_authtoken_middleware $MANILA_CONF glance glance
     fi
-    # Note: set up config group does not mean that this backend will be enabled.
-    # To enable it, specify its name explicitly using "enabled_share_backends" opt.
-    configure_default_backends
-    default_backends=$MANILA_BACKEND1_CONFIG_GROUP_NAME
-    if [ "$MANILA_MULTI_BACKEND" = "True" ]; then
-        default_backends+=,$MANILA_BACKEND2_CONFIG_GROUP_NAME
-    fi
     if [ ! $MANILA_ENABLED_BACKENDS ]; then
-        # If $MANILA_ENABLED_BACKENDS is not set, use configured backends by default
-        export MANILA_ENABLED_BACKENDS=$default_backends
+        # MANILA_ENABLED_BACKENDS is a required option
+        echo -"No configured backends, please set a value to MANILA_ENABLED_BACKENDS"
+        exit 1
     fi
+
+    configure_backends
     iniset $MANILA_CONF DEFAULT enabled_share_backends $MANILA_ENABLED_BACKENDS
 
     if [ ! -f $MANILA_PATH_TO_PRIVATE_KEY ]; then
@@ -496,10 +488,27 @@ function create_manila_accounts {
     get_or_create_endpoint "share" "$REGION_NAME" \
         "$MANILA_ENDPOINT_BASE/v1/\$(project_id)s"
 
-    # Set up Manila v2 service and endpoint
+    # Set up Manila v2 service and endpoint - as of microversion 2.60,
+    # project_id is no longer necessary in the v2 endpoint
     get_or_create_service "manilav2" "sharev2" "Manila Shared Filesystem Service V2"
     get_or_create_endpoint "sharev2" "$REGION_NAME" \
+        "$MANILA_ENDPOINT_BASE/v2"
+
+    # Set up Manila legacy v2 service and endpoint - as of microversion 2.60,
+    # project_id is no longer necessary in the v2 endpoint
+    get_or_create_service "manilav2_legacy" "sharev2_legacy" "Manila Shared
+    Filesystem Service V2 (Legacy 2.0)"
+    get_or_create_endpoint "sharev2_legacy" "$REGION_NAME" \
         "$MANILA_ENDPOINT_BASE/v2/\$(project_id)s"
+
+    # Set up an endpoint for "shared-file-system" - this is necessary to
+    # standardize a naming for the v2 API and for the openstacksdk.
+    # See: https://specs.openstack.org/openstack/service-types-authority/
+    get_or_create_service "shared-file-system" "shared-file-system" "Manila
+    Shared Filesystem Service v2 API (alias of the sharev2 service)"
+    get_or_create_endpoint "shared-file-system" "$REGION_NAME" \
+        "$MANILA_ENDPOINT_BASE/v2"
+
 }
 
 # create_default_share_group_type - create share group type that will be set as default.
@@ -946,10 +955,6 @@ function update_tempest {
         iniset $TEMPEST_CONFIG identity alt_password $ADMIN_PASSWORD
         iniset $TEMPEST_CONFIG identity alt_tenant_name ${ALT_TENANT_NAME:-"alt_demo"}
         iniset $TEMPEST_CONFIG identity alt_domain_name $ADMIN_DOMAIN_NAME
-
-        # Max API micro-version for tempest tests
-        iniset $TEMPEST_CONFIG share min_api_microversion 2.0
-        iniset $TEMPEST_CONFIG share max_api_microversion 2.57
     fi
 }
 
@@ -960,7 +965,7 @@ function install_docker_ubuntu {
 }
 
 function install_docker_fedora {
-    install_package docker
+    sudo yum install -y docker
     sudo systemctl enable docker
     sudo systemctl start docker
 }
@@ -1012,13 +1017,11 @@ function remove_docker_service_image {
 
 
 function install_libraries {
-    if [ $(trueorfalse False MANILA_MULTI_BACKEND) == True ]; then
-        if [ $(trueorfalse True RUN_MANILA_HOST_ASSISTED_MIGRATION_TESTS) == True ]; then
-            if is_ubuntu; then
-                install_package nfs-common
-            else
-                install_package nfs-utils
-            fi
+    if [ $(trueorfalse True RUN_MANILA_HOST_ASSISTED_MIGRATION_TESTS) == True ]; then
+        if is_ubuntu; then
+            install_package nfs-common
+        else
+            install_package nfs-utils
         fi
     fi
 }
@@ -1092,7 +1095,7 @@ function setup_ipv6 {
     # Configure interfaces due to NEUTRON_CREATE_INITIAL_NETWORKS=False
     local ipv4_cidr_len=${FLOATING_RANGE#*/}
     sudo ip -6 addr add "$public_gateway_ipv6"/$SUBNETPOOL_SIZE_V6 dev $PUBLIC_BRIDGE
-    sudo ip addr add $PUBLIC_NETWORK_GATEWAY/"$ipv4_cidr_len" dev $PUBLIC_BRIDGE
+    sudo ip addr add "$public_gateway_ipv4"/"$ipv4_cidr_len" dev $PUBLIC_BRIDGE
 
     # Enabling interface is needed due to NEUTRON_CREATE_INITIAL_NETWORKS=False
     sudo ip link set $PUBLIC_BRIDGE up
@@ -1328,10 +1331,12 @@ elif [[ "$1" == "stack" && "$2" == "test-config" ]]; then
 fi
 
 if [[ "$1" == "unstack" ]]; then
+    stop_manila
     cleanup_manila
 fi
 
 if [[ "$1" == "clean" ]]; then
+    stop_manila
     cleanup_manila
     sudo rm -rf /etc/manila
 fi
