@@ -29,12 +29,11 @@ import socket
 from oslo_config import cfg
 from oslo_log import log
 from oslo_middleware import cors
+from oslo_policy import opts as policy_opts
 from oslo_utils import netutils
-import six
 
 from manila.common import constants
 from manila import exception
-from manila.i18n import _
 
 CONF = cfg.CONF
 log.register_options(CONF)
@@ -129,7 +128,7 @@ global_opts = [
     cfg.StrOpt('auth_strategy',
                default='keystone',
                help='The strategy to use for auth. Supports noauth, keystone, '
-                    'and deprecated.'),
+                    'and noauthv2.'),
     cfg.ListOpt('enabled_share_backends',
                 help='A list of share backend names to use. These backend '
                      'names should be backed by a unique [CONFIG] group '
@@ -137,8 +136,8 @@ global_opts = [
     cfg.ListOpt('enabled_share_protocols',
                 default=['NFS', 'CIFS'],
                 help="Specify list of protocols to be allowed for share "
-                     "creation. Available values are '%s'" % six.text_type(
-                         constants.SUPPORTED_SHARE_PROTOCOLS)),
+                     "creation. Available values are '%s'" %
+                     list(constants.SUPPORTED_SHARE_PROTOCOLS)),
 ]
 
 CONF.register_opts(global_opts)
@@ -163,14 +162,11 @@ def verify_share_protocols():
     if msg:
         msg += ("Please specify one or more protocols using "
                 "configuration option 'enabled_share_protocols'.")
-        # NOTE(vponomaryov): use translation to unicode explicitly,
-        # because of 'lazy' translations.
-        msg = six.text_type(_(msg) % data)  # noqa H701
-        raise exception.ManilaException(message=msg)
+        raise exception.ManilaException(message=msg % data)
 
 
-def set_middleware_defaults():
-    """Update default configuration options for oslo.middleware."""
+def set_lib_defaults():
+    """Update default configuration options for external lib namespace"""
     cors.set_defaults(
         allow_headers=['X-Auth-Token',
                        'X-OpenStack-Request-ID',
@@ -193,3 +189,5 @@ def set_middleware_defaults():
                        'DELETE',
                        'PATCH']
     )
+    # Update default value of oslo.policy policy_file config option.
+    policy_opts.set_defaults(CONF, 'policy.yaml')
