@@ -325,9 +325,19 @@ def share_instance_update(context, instance_id, values, with_share_data=False):
                                       with_share_data=with_share_data)
 
 
-def share_instances_host_update(context, current_host, new_host):
-    """Update the host attr of all share instances that are on current_host."""
-    return IMPL.share_instances_host_update(context, current_host, new_host)
+def share_and_snapshot_instances_status_update(
+        context, values, share_instance_ids=None, snapshot_instance_ids=None,
+        current_expected_status=None):
+    return IMPL.share_and_snapshot_instances_status_update(
+        context, values, share_instance_ids=share_instance_ids,
+        snapshot_instance_ids=snapshot_instance_ids,
+        current_expected_status=current_expected_status)
+
+
+def share_instances_status_update(context, share_instance_ids, values):
+    """Updates the status of a bunch of share instances at once."""
+    return IMPL.share_instances_status_update(
+        context, share_instance_ids, values)
 
 
 def share_instances_get_all(context, filters=None):
@@ -335,10 +345,11 @@ def share_instances_get_all(context, filters=None):
     return IMPL.share_instances_get_all(context, filters=filters)
 
 
-def share_instances_get_all_by_share_server(context, share_server_id):
+def share_instances_get_all_by_share_server(context, share_server_id,
+                                            with_share_data=False):
     """Returns all share instances with given share_server_id."""
-    return IMPL.share_instances_get_all_by_share_server(context,
-                                                        share_server_id)
+    return IMPL.share_instances_get_all_by_share_server(
+        context, share_server_id, with_share_data=with_share_data)
 
 
 def share_instances_get_all_by_host(context, host, with_share_data=False,
@@ -390,13 +401,28 @@ def share_get_all(context, filters=None, sort_key=None, sort_dir=None):
     )
 
 
+def share_get_all_with_count(context, filters=None, sort_key=None,
+                             sort_dir=None):
+    """Get all shares."""
+    return IMPL.share_get_all_with_count(
+        context, filters=filters, sort_key=sort_key, sort_dir=sort_dir)
+
+
 def share_get_all_by_project(context, project_id, filters=None,
                              is_public=False, sort_key=None, sort_dir=None):
     """Returns all shares with given project ID."""
     return IMPL.share_get_all_by_project(
         context, project_id, filters=filters, is_public=is_public,
-        sort_key=sort_key, sort_dir=sort_dir,
-    )
+        sort_key=sort_key, sort_dir=sort_dir)
+
+
+def share_get_all_by_project_with_count(
+        context, project_id, filters=None, is_public=False, sort_key=None,
+        sort_dir=None,):
+    """Returns all shares with given project ID."""
+    return IMPL.share_get_all_by_project_with_count(
+        context, project_id, filters=filters, is_public=is_public,
+        sort_key=sort_key, sort_dir=sort_dir)
 
 
 def share_get_all_by_share_group_id(context, share_group_id,
@@ -408,13 +434,29 @@ def share_get_all_by_share_group_id(context, share_group_id,
         sort_key=sort_key, sort_dir=sort_dir)
 
 
+def share_get_all_by_share_group_id_with_count(context, share_group_id,
+                                               filters=None, sort_key=None,
+                                               sort_dir=None):
+    """Returns all shares with given project ID and share group id."""
+    return IMPL.share_get_all_by_share_group_id_with_count(
+        context, share_group_id, filters=filters, sort_key=sort_key,
+        sort_dir=sort_dir)
+
+
 def share_get_all_by_share_server(context, share_server_id, filters=None,
                                   sort_key=None, sort_dir=None):
     """Returns all shares with given share server ID."""
     return IMPL.share_get_all_by_share_server(
         context, share_server_id, filters=filters, sort_key=sort_key,
-        sort_dir=sort_dir,
-    )
+        sort_dir=sort_dir)
+
+
+def share_get_all_by_share_server_with_count(
+        context, share_server_id, filters=None, sort_key=None, sort_dir=None):
+    """Returns all shares with given share server ID."""
+    return IMPL.share_get_all_by_share_server_with_count(
+        context, share_server_id, filters=filters, sort_key=sort_key,
+        sort_dir=sort_dir)
 
 
 def share_delete(context, share_id):
@@ -518,6 +560,13 @@ def share_snapshot_instance_update(context, instance_id, values):
     return IMPL.share_snapshot_instance_update(context, instance_id, values)
 
 
+def share_snapshot_instances_status_update(
+        context, snapshot_instance_ids, values):
+    """Updates the status of a bunch of share snapshot instances at once."""
+    return IMPL.share_snapshot_instances_status_update(
+        context, snapshot_instance_ids, values)
+
+
 def share_snapshot_instance_create(context, snapshot_id, values):
     """Create a share snapshot instance for an existing snapshot."""
     return IMPL.share_snapshot_instance_create(
@@ -660,6 +709,13 @@ def share_snapshot_instance_export_location_create(context, values):
     return IMPL.share_snapshot_instance_export_location_create(context, values)
 
 
+def share_snapshot_instance_export_locations_update(
+        context, share_snapshot_instance_id, export_locations, delete=True):
+    """Update export locations of a share instance."""
+    return IMPL.share_snapshot_instance_export_locations_update(
+        context, share_snapshot_instance_id, export_locations, delete=delete)
+
+
 def share_snapshot_instance_export_locations_get_all(
         context, share_snapshot_instance_id):
     """Get the share snapshot instance export locations for given id."""
@@ -829,17 +885,34 @@ def share_network_get_all_by_security_service(context, security_service_id):
 
 
 def share_network_add_security_service(context, id, security_service_id):
+    """Associate a security service with a share network."""
     return IMPL.share_network_add_security_service(context,
                                                    id,
                                                    security_service_id)
 
 
 def share_network_remove_security_service(context, id, security_service_id):
+    """Dissociate a security service from a share network."""
     return IMPL.share_network_remove_security_service(context,
                                                       id,
                                                       security_service_id)
 
 
+def share_network_security_service_association_get(
+        context, share_network_id, security_service_id):
+    """Get given share network and security service association."""
+    return IMPL.share_network_security_service_association_get(
+        context, share_network_id, security_service_id)
+
+
+def share_network_update_security_service(context, id,
+                                          current_security_service_id,
+                                          new_security_service_id):
+    """Update a security service association with a share network."""
+    return IMPL.share_network_update_security_service(
+        context, id, current_security_service_id, new_security_service_id)
+
+
 def count_share_networks(context, project_id, user_id=None,
                          share_type_id=None, session=None):
     return IMPL.count_share_networks(
@@ -975,9 +1048,14 @@ def share_server_get_all(context):
     return IMPL.share_server_get_all(context)
 
 
-def share_server_get_all_by_host(context, host):
+def share_server_get_all_with_filters(context, filters):
+    """Get all share servers that match with the specified filters."""
+    return IMPL.share_server_get_all_with_filters(context, filters)
+
+
+def share_server_get_all_by_host(context, host, filters=None):
     """Get all share servers related to particular host."""
-    return IMPL.share_server_get_all_by_host(context, host)
+    return IMPL.share_server_get_all_by_host(context, host, filters=filters)
 
 
 def share_server_get_all_unused_deletable(context, host, updated_before):
@@ -992,6 +1070,12 @@ def share_server_backend_details_set(context, share_server_id, server_details):
                                                  server_details)
 
 
+def share_servers_update(context, share_server_ids, values):
+    """Updates values of a bunch of share servers at once."""
+    return IMPL.share_servers_update(
+        context, share_server_ids, values)
+
+
 ##################
 
 
@@ -1265,6 +1349,11 @@ def share_group_snapshot_member_update(context, member_id, values):
     return IMPL.share_group_snapshot_member_update(context, member_id, values)
 
 
+def share_resources_host_update(context, current_host, new_host):
+    """Update the host attr of all share resources that are on current_host."""
+    return IMPL.share_resources_host_update(context, current_host, new_host)
+
+
 ####################
 
 def share_replicas_get_all(context, with_share_server=False,
@@ -1448,3 +1537,22 @@ def backend_info_update(context, host, value=None,
     """Update hash info for host."""
     return IMPL.backend_info_update(context, host=host, value=value,
                                     delete_existing=delete_existing)
+
+####################
+
+
+def async_operation_data_get(context, entity_id, key=None, default=None):
+    """Get one, list or all key-value pairs for given entity_id."""
+    return IMPL.async_operation_data_get(context, entity_id, key, default)
+
+
+def async_operation_data_update(context, entity_id, details,
+                                delete_existing=False):
+    """Update key-value pairs for given entity_id."""
+    return IMPL.async_operation_data_update(context, entity_id, details,
+                                            delete_existing)
+
+
+def async_operation_data_delete(context, entity_id, key=None):
+    """Remove one, list or all key-value pairs for given entity_id."""
+    return IMPL.async_operation_data_delete(context, entity_id, key)
