@@ -81,14 +81,6 @@ class Service(BASE, ManilaBase):
     )
 
 
-class ManilaNode(BASE, ManilaBase):
-    """Represents a running manila service on a host."""
-
-    __tablename__ = 'manila_nodes'
-    id = Column(Integer, primary_key=True)
-    service_id = Column(Integer, ForeignKey('services.id'), nullable=True)
-
-
 class Quota(BASE, ManilaBase):
     """Represents a single quota override for a project.
 
@@ -272,8 +264,10 @@ class Share(BASE, ManilaBase):
         if len(self.instances) > 0:
             order = (constants.STATUS_REVERTING,
                      constants.STATUS_REPLICATION_CHANGE,
-                     constants.STATUS_MIGRATING, constants.STATUS_AVAILABLE,
-                     constants.STATUS_ERROR)
+                     constants.STATUS_MIGRATING,
+                     constants.STATUS_SERVER_MIGRATING,
+                     constants.STATUS_AVAILABLE,
+                     constants.STATUS_ERROR, )
             other_statuses = (
                 [x['status'] for x in self.instances if
                  x['status'] not in order and
@@ -679,8 +673,9 @@ class ShareSnapshot(BASE, ManilaBase):
                 lambda x: qualified_replica(x.share_instance), self.instances))
 
             migrating_snapshots = list(filter(
-                lambda x: x.share_instance['status'] ==
-                constants.STATUS_MIGRATING, self.instances))
+                lambda x: x.share_instance['status'] in (
+                    constants.STATUS_MIGRATING,
+                    constants.STATUS_SERVER_MIGRATING), self.instances))
 
             snapshot_instances = (replica_snapshots or migrating_snapshots
                                   or self.instances)
@@ -712,6 +707,7 @@ class ShareSnapshot(BASE, ManilaBase):
 
         order = (constants.STATUS_DELETING, constants.STATUS_CREATING,
                  constants.STATUS_ERROR, constants.STATUS_MIGRATING,
+                 constants.STATUS_SERVER_MIGRATING,
                  constants.STATUS_AVAILABLE)
         other_statuses = [x['status'] for x in self.instances if
                           x['status'] not in order]
@@ -924,6 +920,10 @@ class ShareNetwork(BASE, ManilaBase):
     user_id = Column(String(255), nullable=False)
     name = Column(String(255), nullable=True)
     description = Column(String(255), nullable=True)
+    status = Column(Enum(
+        constants.STATUS_NETWORK_ACTIVE, constants.STATUS_NETWORK_ERROR,
+        constants.STATUS_NETWORK_CHANGE),
+        default=constants.STATUS_NETWORK_ACTIVE)
     security_services = orm.relationship(
         "SecurityService",
         secondary="share_network_security_service_association",
@@ -939,7 +939,7 @@ class ShareNetwork(BASE, ManilaBase):
         'SecurityService.deleted == "False")')
     share_instances = orm.relationship(
         "ShareInstance",
-        backref='share_network',
+        backref=orm.backref('share_network'),
         primaryjoin='and_('
                     'ShareNetwork.id == ShareInstance.share_network_id,'
                     'ShareInstance.deleted == "False")')
@@ -951,6 +951,18 @@ class ShareNetwork(BASE, ManilaBase):
                     '(ShareNetwork.id == ShareNetworkSubnet.share_network_id,'
                     'ShareNetworkSubnet.deleted == "False")')
 
+    @property
+    def security_service_update_support(self):
+        share_servers_support_updating = []
+        for network_subnet in self.share_network_subnets:
+            for server in network_subnet['share_servers']:
+                share_servers_support_updating.append(
+                    server['security_service_update_support'])
+        # NOTE(carloss): all share servers within this share network must
+        # support updating security services in order to have this property
+        # set to True.
+        return all(share_servers_support_updating)
+
 
 class ShareNetworkSubnet(BASE, ManilaBase):
     """Represents a share network subnet used by some resources."""
@@ -1014,12 +1026,20 @@ class ShareServer(BASE, ManilaBase):
     host = Column(String(255), nullable=False)
     is_auto_deletable = Column(Boolean, default=True)
     identifier = Column(String(255), nullable=True)
+    task_state = Column(String(255), nullable=True)
+    source_share_server_id = Column(String(36), ForeignKey('share_servers.id'),
+                                    nullable=True)
+    security_service_update_support = Column(
+        Boolean, nullable=False, default=False)
     status = Column(Enum(
         constants.STATUS_INACTIVE, constants.STATUS_ACTIVE,
         constants.STATUS_ERROR, constants.STATUS_DELETING,
         constants.STATUS_CREATING, constants.STATUS_DELETED,
         constants.STATUS_MANAGING, constants.STATUS_UNMANAGING,
-        constants.STATUS_UNMANAGE_ERROR, constants.STATUS_MANAGE_ERROR),
+        constants.STATUS_UNMANAGE_ERROR, constants.STATUS_MANAGE_ERROR,
+        constants.STATUS_SERVER_MIGRATING,
+        constants.STATUS_SERVER_MIGRATING_TO,
+        constants.STATUS_SERVER_NETWORK_CHANGE),
         default=constants.STATUS_INACTIVE)
     network_allocations = orm.relationship(
         "NetworkAllocation",
@@ -1308,6 +1328,14 @@ class BackendInfo(BASE, ManilaBase):
     info_hash = Column(String(255))
 
 
+class AsynchronousOperationData(BASE, ManilaBase):
+    """Represents data as key-value pairs for asynchronous operations."""
+    __tablename__ = 'async_operation_data'
+    entity_uuid = Column(String(36), nullable=False, primary_key=True)
+    key = Column(String(255), nullable=False, primary_key=True)
+    value = Column(String(1023), nullable=False)
+
+
 def register_models():
     """Register Models and create metadata.
 
