@@ -242,12 +242,24 @@ class ShareServerNotFoundByFilters(ShareServerNotFound):
                 "filters: %(filters_description)s.")
 
 
+class InvalidShareNetwork(Invalid):
+    message = _("Invalid share network: %(reason)s")
+
+
 class ShareServerInUse(InUse):
     message = _("Share server %(share_server_id)s is in use.")
 
 
+class ShareServerMigrationError(ManilaException):
+    message = _("Error in share server migration: %(reason)s")
+
+
+class ShareServerMigrationFailed(ManilaException):
+    message = _("Share server migration failed: %(reason)s")
+
+
 class InvalidShareServer(Invalid):
-    message = _("Share server %(share_server_id)s is not valid.")
+    message = _("Invalid share server: %(reason)s")
 
 
 class ShareMigrationError(ManilaException):
@@ -416,6 +428,12 @@ class SnapshotSizeExceedsAvailableQuota(QuotaError):
         "gigabytes quota.")
 
 
+class ShareSizeExceedsLimit(QuotaError):
+    message = _(
+        "Requested share size %(size)d is larger than "
+        "maximum allowed limit %(limit)d.")
+
+
 class ShareLimitExceeded(QuotaError):
     message = _(
         "Maximum number of shares allowed (%(allowed)d) either per "
@@ -583,6 +601,10 @@ class SecurityServiceNotFound(NotFound):
     message = _("Security service %(security_service_id)s could not be found.")
 
 
+class InvalidSecurityService(Invalid):
+    message = _("Invalid security service: %(reason)s")
+
+
 class ShareNetworkSecurityServiceAssociationError(ManilaException):
     message = _("Failed to associate share network %(share_network_id)s"
                 " and security service %(security_service_id)s: %(reason)s.")
@@ -593,6 +615,10 @@ class ShareNetworkSecurityServiceDissociationError(ManilaException):
                 " and security service %(security_service_id)s: %(reason)s.")
 
 
+class SecurityServiceFailedAuth(ManilaException):
+    message = _("Failed to authenticate user against security service.")
+
+
 class InvalidVolume(Invalid):
     message = _("Invalid volume.")
 
@@ -775,6 +801,10 @@ class VserverNotSpecified(NetAppException):
     message = _("Vserver not specified.")
 
 
+class VserverNotReady(NetAppException):
+    message = _("Vserver %(vserver)s is not ready yet.")
+
+
 class EMCPowerMaxXMLAPIError(Invalid):
     message = _("%(err)s")
 
@@ -1001,3 +1031,76 @@ class InfortrendCLIException(ShareBackendException):
 
 class InfortrendNASException(ShareBackendException):
     message = _("Infortrend NAS exception: %(err)s")
+
+
+# Zadara storage driver
+class ZadaraUnknownCmd(ShareBackendException):
+    message = _("Unknown or unsupported command %(cmd)s")
+
+
+class ZadaraSessionRequestException(ShareBackendException):
+    message = _("%(msg)s")
+
+
+class ZadaraBadHTTPResponseStatus(ShareBackendException):
+    message = _("Bad HTTP response status %(status)s")
+
+
+class ZadaraFailedCmdWithDump(ShareBackendException):
+    message = _("Operation failed with status=%(status)s. Full dump: %(data)s")
+
+
+class ZadaraVPSANoActiveController(ShareBackendException):
+    message = _("Unable to find any active VPSA controller")
+
+
+class ZadaraServerCreateFailure(ShareBackendException):
+    message = _("Unable to create server object for initiator %(name)s")
+
+
+class ZadaraAttachmentsNotFound(ShareBackendException):
+    message = _("Failed to retrieve attachments for volume %(name)s")
+
+
+class ZadaraManilaInvalidAccessKey(ShareBackendException):
+    message = _("Invalid VPSA access key")
+
+
+class ZadaraVPSAVolumeShareFailed(ShareBackendException):
+    message = _("Failed to create VPSA backend share. Error: %(error)s")
+
+
+class ZadaraInvalidShareAccessType(ShareBackendException):
+    message = _("Only ip access type allowed for the Zadara manila share.")
+
+
+class ZadaraShareNotFound(ShareBackendException):
+    message = _("Share %(name)s could not be found.")
+
+
+class ZadaraExtendShareFailed(ShareBackendException):
+    message = _("Failed to extend VPSA backend share. Error: %(error)s")
+
+
+class ZadaraInvalidProtocol(ShareBackendException):
+    message = _("The type of protocol %(protocol_type)s for Zadara "
+                "manila driver is not supported. Only NFS or CIFS "
+                "protocol is supported.")
+
+
+class ZadaraShareNotValid(ShareBackendException):
+    message = _("Share %(name)s is not valid.")
+
+
+class ZadaraVPSASnapshotCreateFailed(ShareBackendException):
+    message = _("Failed to create VPSA share %(name)s snapshot. "
+                "Error: %(error)s")
+
+
+class ZadaraVPSASnapshotManageFailed(ShareBackendException):
+    message = _("Failed to manage VPSA share snapshot with id %(snap_id)s. "
+                "Error: %(error)s")
+
+
+class ZadaraServerNotFound(NotFound):
+    message = _("Unable to find server object for initiator %(name)s")
