@@ -51,6 +51,8 @@ This module provides Manager, a base class for managers.
 
 """
 
+
+from eventlet import greenpool
 from oslo_config import cfg
 from oslo_log import log
 from oslo_service import periodic_task
@@ -101,19 +103,7 @@ class Manager(base.Base, PeriodicTasks):
     def init_host(self):
         """Handle initialization if this is a standalone service.
 
-        A hook point for services to execute tasks before the services are made
-        available (i.e. showing up on RPC and starting to accept RPC calls) to
-        other components.  Child classes should override this method.
-
-        """
-        pass
-
-    def init_host_with_rpc(self):
-        """A hook for service to do jobs after RPC is ready.
-
-        Like init_host(), this method is a hook where services get a chance
-        to execute tasks that *need* RPC. Child classes should override
-        this method.
+        Child classes should override this method.
 
         """
         pass
@@ -151,8 +141,12 @@ class SchedulerDependentManager(Manager):
         self.last_capabilities = None
         self.service_name = service_name
         self.scheduler_rpcapi = scheduler_rpcapi.SchedulerAPI()
+        self._tp = greenpool.GreenPool()
         super(SchedulerDependentManager, self).__init__(host, db_driver)
 
+    def _add_to_threadpool(self, func, *args, **kwargs):
+        self._tp.spawn_n(func, *args, **kwargs)
+
     def update_service_capabilities(self, capabilities):
         """Remember these capabilities to send on next periodic update."""
         self.last_capabilities = capabilities
