@@ -39,6 +39,7 @@ from manila import coordination
 from manila.db import migration
 from manila.db.sqlalchemy import api as db_api
 from manila.db.sqlalchemy import models as db_models
+from manila import policy
 from manila import rpc
 from manila import service
 from manila.tests import conf_fixture
@@ -153,12 +154,31 @@ class TestCase(base_test.BaseTestCase):
 
         fake_notifier.stub_notifier(self)
 
+        self._disable_osprofiler()
+
         # Locks must be cleaned up after tests
         CONF.set_override('backend_url', 'file://' + lock_path,
                           group='coordination')
         coordination.LOCK_COORDINATOR.start()
         self.addCleanup(coordination.LOCK_COORDINATOR.stop)
 
+        # policy
+        policy.init(suppress_deprecation_warnings=True)
+        self.addCleanup(policy.reset)
+
+    def _disable_osprofiler(self):
+        """Disable osprofiler.
+
+        osprofiler should not run for unit tests.
+        """
+
+        def side_effect(value):
+            return value
+        mock_decorator = mock.MagicMock(side_effect=side_effect)
+        p = mock.patch("osprofiler.profiler.trace_cls",
+                       return_value=mock_decorator)
+        p.start()
+
     def tearDown(self):
         """Runs after each test method to tear down test environment."""
         super(TestCase, self).tearDown()
