@@ -12,14 +12,16 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from unittest import mock
+
 import ddt
-import mock
 from oslo_utils import uuidutils
 from webob import exc
 
 from manila.api.openstack import api_version_request as api_version
 from manila.api.v1 import scheduler_stats
 from manila import context
+from manila import exception
 from manila import policy
 from manila.scheduler import rpcapi
 from manila.share import share_types
@@ -101,7 +103,8 @@ class SchedulerStatsControllerTestCase(test.TestCase):
         }
 
         self.assertDictMatch(result, expected)
-        mock_get_pools.assert_called_once_with(self.ctxt, filters={})
+        mock_get_pools.assert_called_once_with(self.ctxt, filters={},
+                                               cached=True)
         self.mock_policy_check.assert_called_once_with(
             self.ctxt, self.resource_name, 'index')
 
@@ -148,7 +151,8 @@ class SchedulerStatsControllerTestCase(test.TestCase):
 
         self.assertDictMatch(result, expected_result)
         mock_get_pools.assert_called_once_with(self.ctxt,
-                                               filters=expected_filters)
+                                               filters=expected_filters,
+                                               cached=True)
 
     @ddt.data(('index', False, True),
               ('index', False, False),
@@ -210,7 +214,8 @@ class SchedulerStatsControllerTestCase(test.TestCase):
 
         self.assertDictMatch(result, expected_result)
         mock_get_pools.assert_called_once_with(self.ctxt,
-                                               filters=expected_filters)
+                                               filters=expected_filters,
+                                               cached=True)
 
     @ddt.data('index', 'detail')
     def test_pools_with_share_type_not_found(self, action):
@@ -271,7 +276,8 @@ class SchedulerStatsControllerTestCase(test.TestCase):
 
         self.assertDictMatch(result, expected)
         mock_get_pools.assert_called_once_with(self.ctxt,
-                                               filters=expected_filters)
+                                               filters=expected_filters,
+                                               cached=True)
         self.mock_policy_check.assert_called_once_with(
             self.ctxt, self.resource_name, 'index')
 
@@ -323,10 +329,29 @@ class SchedulerStatsControllerTestCase(test.TestCase):
         }
 
         self.assertDictMatch(expected, result)
-        mock_get_pools.assert_called_once_with(self.ctxt, filters={})
+        mock_get_pools.assert_called_once_with(self.ctxt, filters={},
+                                               cached=True)
         self.mock_policy_check.assert_called_once_with(
             self.ctxt, self.resource_name, 'detail')
 
+    @ddt.data('index', 'detail')
+    def test_pools_forbidden(self, subresource):
+        mock_get_pools = self.mock_object(
+            rpcapi.SchedulerAPI, 'get_pools',
+            mock.Mock(side_effect=exception.AdminRequired(
+                "some traceback here")))
+        path = '/v1/fake_project/scheduler_stats/pools'
+        path = path + ('/%s' % subresource if subresource == 'detail' else '')
+        req = fakes.HTTPRequest.blank(path)
+        req.environ['manila.context'] = self.ctxt
+
+        self.assertRaises(exc.HTTPForbidden,
+                          getattr(self.controller, 'pools_%s' % subresource),
+                          req)
+        mock_get_pools.assert_called_once_with(self.ctxt,
+                                               filters={},
+                                               cached=True)
+
 
 class SchedulerStatsTestCase(test.TestCase):
 
