@@ -14,9 +14,9 @@
 
 from copy import deepcopy
 import sys
+from unittest import mock
 
 import ddt
-import mock
 if 'hpe3parclient' not in sys.modules:
     sys.modules['hpe3parclient'] = mock.Mock()
 
@@ -438,8 +438,8 @@ class HPE3ParDriverTestCase(test.TestCase):
     def test_driver_create_cifs_share(self):
         self.init_driver()
 
-        expected_location = '\\\\%s\%s' % (constants.EXPECTED_IP_10203040,
-                                           constants.EXPECTED_SHARE_NAME)
+        expected_location = '\\\\%s\\%s' % (constants.EXPECTED_IP_10203040,
+                                            constants.EXPECTED_SHARE_NAME)
 
         self.mock_mediator.create_share.return_value = (
             constants.EXPECTED_SHARE_NAME)
@@ -496,8 +496,8 @@ class HPE3ParDriverTestCase(test.TestCase):
     def test_driver_create_cifs_share_from_snapshot(self):
         self.init_driver()
 
-        expected_location = '\\\\%s\%s' % (constants.EXPECTED_IP_10203040,
-                                           constants.EXPECTED_SHARE_NAME)
+        expected_location = '\\\\%s\\%s' % (constants.EXPECTED_IP_10203040,
+                                            constants.EXPECTED_SHARE_NAME)
 
         self.mock_mediator.create_share_from_snapshot.return_value = (
             constants.EXPECTED_SHARE_NAME)
@@ -746,6 +746,9 @@ class HPE3ParDriverTestCase(test.TestCase):
             'goodness_function': None,
             'ipv4_support': True,
             'ipv6_support': False,
+            'max_share_server_size': -1,
+            'max_shares_per_share_server': -1,
+            'security_service_update_support': False,
         }
 
         result = self.driver.get_share_stats(refresh=True)
@@ -799,6 +802,8 @@ class HPE3ParDriverTestCase(test.TestCase):
             'provisioned_capacity_gb': 0,
             'reserved_percentage': 0,
             'max_over_subscription_ratio': None,
+            'max_share_server_size': -1,
+            'max_shares_per_share_server': -1,
             'qos': False,
             'thin_provisioning': True,
             'pools': [{
@@ -814,6 +819,7 @@ class HPE3ParDriverTestCase(test.TestCase):
             'snapshot_support': True,
             'create_share_from_snapshot_support': True,
             'revert_to_snapshot_support': False,
+            'security_service_update_support': False,
             'mount_snapshot_support': False,
             'share_group_stats': {
                 'consistent_snapshot_support': None,
@@ -847,6 +853,8 @@ class HPE3ParDriverTestCase(test.TestCase):
             'driver_version': expected_version,
             'free_capacity_gb': 0,
             'max_over_subscription_ratio': None,
+            'max_share_server_size': -1,
+            'max_shares_per_share_server': -1,
             'pools': None,
             'provisioned_capacity_gb': 0,
             'reserved_percentage': 0,
@@ -858,6 +866,7 @@ class HPE3ParDriverTestCase(test.TestCase):
             'snapshot_support': True,
             'create_share_from_snapshot_support': True,
             'revert_to_snapshot_support': False,
+            'security_service_update_support': False,
             'mount_snapshot_support': False,
             'share_group_stats': {
                 'consistent_snapshot_support': None,
