@@ -34,38 +34,38 @@ class ShareRpcAPITestCase(test.TestCase):
 
     def setUp(self):
         super(ShareRpcAPITestCase, self).setUp()
-        self.context = context.get_admin_context()
         share = db_utils.create_share(
             availability_zone=CONF.storage_availability_zone,
             status=constants.STATUS_AVAILABLE
         )
-        access = db_utils.create_access(share_id=share['id'])
         snapshot = db_utils.create_snapshot(share_id=share['id'])
         share_replica = db_utils.create_share_replica(
             id='fake_replica',
             share_id='fake_share_id',
             host='fake_host',
         )
-        share_server = db_utils.create_share_server()
-        cg = {'id': 'fake_cg_id', 'host': 'fake_host'}
-        cgsnapshot = {'id': 'fake_cg_id'}
+        share_group = {'id': 'fake_share_group_id', 'host': 'fake_host'}
+        share_group_snapshot = {'id': 'fake_share_group_id'}
         host = 'fake_host'
+        share_server = db_utils.create_share_server(host=host)
         self.fake_share = jsonutils.to_primitive(share)
         # mock out the getattr on the share db model object since jsonutils
         # doesn't know about those extra attributes to pull in
         self.fake_share['instance'] = jsonutils.to_primitive(share.instance)
         self.fake_share_replica = jsonutils.to_primitive(share_replica)
-        self.fake_access = jsonutils.to_primitive(access)
         self.fake_snapshot = jsonutils.to_primitive(snapshot)
+        self.fake_snapshot['share_instance'] = jsonutils.to_primitive(
+            snapshot.instance)
         self.fake_share_server = jsonutils.to_primitive(share_server)
-        self.fake_cg = jsonutils.to_primitive(cg)
-        self.fake_cgsnapshot = jsonutils.to_primitive(cgsnapshot)
+        self.fake_share_group = jsonutils.to_primitive(share_group)
+        self.fake_share_group_snapshot = jsonutils.to_primitive(
+            share_group_snapshot)
         self.fake_host = jsonutils.to_primitive(host)
         self.ctxt = context.RequestContext('fake_user', 'fake_project')
         self.rpcapi = share_rpcapi.ShareAPI()
 
     def test_serialized_share_has_id(self):
-        self.assertTrue('id' in self.fake_share)
+        self.assertIn('id', self.fake_share)
 
     def _test_share_api(self, method, rpc_method, **kwargs):
         expected_retval = 'foo' if method == 'call' else None
@@ -81,18 +81,14 @@ class ShareRpcAPITestCase(test.TestCase):
         if 'share_instance' in expected_msg:
             share_instance = expected_msg.pop('share_instance', None)
             expected_msg['share_instance_id'] = share_instance['id']
-        if 'cg' in expected_msg:
-            cg = expected_msg['cg']
-            del expected_msg['cg']
-            expected_msg['cg_id'] = cg['id']
-        if 'cgsnapshot' in expected_msg:
-            snap = expected_msg['cgsnapshot']
-            del expected_msg['cgsnapshot']
-            expected_msg['cgsnapshot_id'] = snap['id']
-        if 'access' in expected_msg:
-            access = expected_msg['access']
-            del expected_msg['access']
-            expected_msg['access_rules'] = [access['id']]
+        if 'share_group' in expected_msg:
+            share_group = expected_msg['share_group']
+            del expected_msg['share_group']
+            expected_msg['share_group_id'] = share_group['id']
+        if 'share_group_snapshot' in expected_msg:
+            snap = expected_msg['share_group_snapshot']
+            del expected_msg['share_group_snapshot']
+            expected_msg['share_group_snapshot_id'] = snap['id']
         if 'host' in expected_msg:
             del expected_msg['host']
         if 'snapshot' in expected_msg:
@@ -113,11 +109,36 @@ class ShareRpcAPITestCase(test.TestCase):
         if 'src_share_instance' in expected_msg:
             share_instance = expected_msg.pop('src_share_instance', None)
             expected_msg['src_instance_id'] = share_instance['id']
+        if 'update_access' in expected_msg:
+            share_instance = expected_msg.pop('share_instance', None)
+            expected_msg['share_instance_id'] = share_instance['id']
+        if 'snapshot_instance' in expected_msg:
+            snapshot_instance = expected_msg.pop('snapshot_instance', None)
+            expected_msg['snapshot_instance_id'] = snapshot_instance['id']
+        share_server_id_methods = [
+            'manage_share_server', 'unmanage_share_server',
+            'share_server_migration_start', 'share_server_migration_check']
+        src_dest_share_server_methods = [
+            'share_server_migration_cancel',
+            'share_server_migration_get_progress',
+            'share_server_migration_complete']
+        if ('share_server' in expected_msg
+                and method in share_server_id_methods):
+            share_server = expected_msg.pop('share_server', None)
+            expected_msg['share_server_id'] = share_server['id']
+        if ('share_server' in expected_msg
+                and method in src_dest_share_server_methods):
+            share_server = expected_msg.pop('share_server', None)
+            expected_msg['src_share_server_id'] = share_server['id']
+        if ('dest_share_server' in expected_msg
+                and method in src_dest_share_server_methods):
+            share_server = expected_msg.pop('dest_share_server', None)
+            expected_msg['dest_share_server_id'] = share_server['id']
 
         if 'host' in kwargs:
             host = kwargs['host']
-        elif 'cg' in kwargs:
-            host = kwargs['cg']['host']
+        elif 'share_group' in kwargs:
+            host = kwargs['share_group']['host']
         elif 'share_instance' in kwargs:
             host = kwargs['share_instance']['host']
         elif 'share_server' in kwargs:
@@ -177,19 +198,11 @@ class ShareRpcAPITestCase(test.TestCase):
                              share_instance=self.fake_share,
                              force=False)
 
-    def test_allow_access(self):
-        self._test_share_api('allow_access',
+    def test_update_access(self):
+        self._test_share_api('update_access',
                              rpc_method='cast',
-                             version='1.7',
-                             share_instance=self.fake_share,
-                             access=self.fake_access)
-
-    def test_deny_access(self):
-        self._test_share_api('deny_access',
-                             rpc_method='cast',
-                             version='1.7',
-                             share_instance=self.fake_share,
-                             access=self.fake_access)
+                             version='1.14',
+                             share_instance=self.fake_share)
 
     def test_create_snapshot(self):
         self._test_share_api('create_snapshot',
@@ -224,43 +237,46 @@ class ShareRpcAPITestCase(test.TestCase):
                              share=self.fake_share,
                              new_size=123)
 
-    def test_create_consistency_group(self):
-        self._test_share_api('create_consistency_group',
-                             version='1.5',
+    def test_create_share_group(self):
+        self._test_share_api('create_share_group',
+                             version='1.16',
                              rpc_method='cast',
-                             cg=self.fake_cg,
+                             share_group=self.fake_share_group,
                              host='fake_host1')
 
-    def test_delete_consistency_group(self):
-        self._test_share_api('delete_consistency_group',
-                             version='1.5',
+    def test_delete_share_group(self):
+        self._test_share_api('delete_share_group',
+                             version='1.16',
                              rpc_method='cast',
-                             cg=self.fake_cg)
+                             share_group=self.fake_share_group)
 
-    def test_create_cgsnapshot(self):
-        self._test_share_api('create_cgsnapshot',
-                             version='1.5',
-                             rpc_method='cast',
-                             cgsnapshot=self.fake_cgsnapshot,
-                             host='fake_host1')
+    def test_create_share_group_snapshot(self):
+        self._test_share_api(
+            'create_share_group_snapshot',
+            version='1.16',
+            rpc_method='cast',
+            share_group_snapshot=self.fake_share_group_snapshot,
+            host='fake_host1')
 
-    def test_delete_cgsnapshot(self):
-        self._test_share_api('delete_cgsnapshot',
-                             version='1.5',
-                             rpc_method='cast',
-                             cgsnapshot=self.fake_cgsnapshot,
-                             host='fake_host1')
+    def test_delete_share_group_snapshot(self):
+        self._test_share_api(
+            'delete_share_group_snapshot',
+            version='1.16',
+            rpc_method='cast',
+            share_group_snapshot=self.fake_share_group_snapshot,
+            host='fake_host1')
 
     def test_migration_start(self):
         self._test_share_api('migration_start',
                              rpc_method='cast',
-                             version='1.12',
+                             version='1.15',
                              share=self.fake_share,
                              dest_host=self.fake_host,
                              force_host_assisted_migration=True,
                              preserve_metadata=True,
                              writable=True,
                              nondisruptive=False,
+                             preserve_snapshots=True,
                              new_share_network_id='fake_net_id',
                              new_share_type_id='fake_type_id')
 
@@ -325,6 +341,30 @@ class ShareRpcAPITestCase(test.TestCase):
                              snapshot=self.fake_snapshot,
                              host='fake_host')
 
+    def test_manage_share_server(self):
+        self._test_share_api('manage_share_server',
+                             rpc_method='cast',
+                             version='1.19',
+                             share_server=self.fake_share_server,
+                             identifier='fake',
+                             driver_opts={})
+
+    def test_unmanage_share_server(self):
+        self._test_share_api('unmanage_share_server',
+                             rpc_method='cast',
+                             version='1.19',
+                             share_server=self.fake_share_server,
+                             force='fake_force')
+
+    def test_revert_to_snapshot(self):
+        self._test_share_api('revert_to_snapshot',
+                             rpc_method='cast',
+                             version='1.18',
+                             share=self.fake_share,
+                             snapshot=self.fake_snapshot,
+                             host='fake_host',
+                             reservations={'fake': 'fake'})
+
     def test_create_replicated_snapshot(self):
         self._test_share_api('create_replicated_snapshot',
                              rpc_method='cast',
@@ -352,6 +392,87 @@ class ShareRpcAPITestCase(test.TestCase):
     def test_create_share_server(self):
         self._test_share_api('create_share_server',
                              rpc_method='cast',
-                             version='1.12',
+                             version='1.20',
                              share_instance=self.fake_share['instance'],
                              share_server_id='fake_server_id')
+
+    def test_snapshot_update_access(self):
+        self._test_share_api('snapshot_update_access',
+                             rpc_method='cast',
+                             version='1.17',
+                             snapshot_instance=self.fake_snapshot[
+                                 'share_instance'])
+
+    def test_share_server_migration_start(self):
+        self._test_share_api('share_server_migration_start',
+                             rpc_method='cast',
+                             version='1.21',
+                             share_server=self.fake_share_server,
+                             dest_host=self.fake_host,
+                             writable=True,
+                             nondisruptive=False,
+                             preserve_snapshots=True,
+                             new_share_network_id='fake_share_network_id')
+
+    def test_share_server_migration_check(self):
+        self._test_share_api('share_server_migration_check',
+                             rpc_method='call',
+                             version='1.21',
+                             share_server_id=self.fake_share_server['id'],
+                             dest_host=self.fake_host,
+                             writable=True,
+                             nondisruptive=False,
+                             preserve_snapshots=True,
+                             new_share_network_id='fake_net_id')
+
+    def test_share_server_migration_cancel(self):
+        self._test_share_api('share_server_migration_cancel',
+                             rpc_method='cast',
+                             version='1.21',
+                             dest_host=self.fake_host,
+                             share_server=self.fake_share_server,
+                             dest_share_server=self.fake_share_server)
+
+    def test_share_server_migration_get_progress(self):
+        self._test_share_api('share_server_migration_get_progress',
+                             rpc_method='call',
+                             version='1.21',
+                             dest_host=self.fake_host,
+                             share_server=self.fake_share_server,
+                             dest_share_server=self.fake_share_server)
+
+    def test_share_server_migration_complete(self):
+        self._test_share_api('share_server_migration_complete',
+                             rpc_method='cast',
+                             version='1.21',
+                             dest_host=self.fake_host,
+                             share_server=self.fake_share_server,
+                             dest_share_server=self.fake_share_server)
+
+    def test_update_access_for_share_instances(self):
+        self._test_share_api(
+            'update_access_for_instances',
+            rpc_method='cast',
+            version='1.21',
+            dest_host=self.fake_host,
+            share_instance_ids=[self.fake_share['instance']['id']],
+            share_server_id=self.fake_share_server['id'])
+
+    def test_update_share_network_security_service(self):
+        self._test_share_api(
+            'update_share_network_security_service',
+            rpc_method='cast',
+            version='1.22',
+            dest_host=self.fake_host,
+            share_network_id='fake_net_id',
+            new_security_service_id='fake_sec_service_id',
+            current_security_service_id='fake_sec_service_id')
+
+    def test_check_update_share_network_security_service(self):
+        self._test_share_api('check_update_share_network_security_service',
+                             rpc_method='cast',
+                             version='1.22',
+                             dest_host=self.fake_host,
+                             share_network_id='fake_net_id',
+                             new_security_service_id='fake_sec_service_id',
+                             current_security_service_id='fake_sec_service_id')
