@@ -354,6 +354,7 @@ class DbQuotaDriverTestCase(test.TestCase):
             'project_id': self.ctxt.project_id,
             'user_id': self.ctxt.user_id,
             'share_type_id': None,
+            'overquota_allowed': False
         }
         expected_kwargs.update(kwargs)
         st_quotas = st_quotas if kwargs.get('share_type_id') else {}
@@ -625,7 +626,8 @@ class QuotaEngineTestCase(test.TestCase):
         self.driver.reserve.assert_called_once_with(
             self.ctxt, self.engine._resources, {'delta1': 1, 'delta2': 2},
             expire='fake_expire', project_id=self.project_id,
-            user_id=self.user_id, share_type_id=self.share_type_id)
+            user_id=self.user_id, share_type_id=self.share_type_id,
+            overquota_allowed=False)
 
     @ddt.data(Exception('FakeException'), [None])
     def test_commit(self, side_effect):
@@ -712,7 +714,7 @@ class QuotaEngineTestCase(test.TestCase):
 
     def test_current_common_resources(self):
         self.assertEqual(
-            ['gigabytes', 'replica_gigabytes', 'share_group_snapshots',
-             'share_groups', 'share_networks', 'share_replicas', 'shares',
-             'snapshot_gigabytes', 'snapshots'],
+            ['gigabytes', 'per_share_gigabytes', 'replica_gigabytes',
+             'share_group_snapshots', 'share_groups', 'share_networks',
+             'share_replicas', 'shares', 'snapshot_gigabytes', 'snapshots'],
             quota.QUOTAS.resources)
