@@ -15,18 +15,16 @@
 #    under the License.
 
 import datetime
-import errno
 import json
-import socket
 import time
+from unittest import mock
 
 import ddt
-import mock
 from oslo_config import cfg
+from oslo_utils import encodeutils
 from oslo_utils import timeutils
 from oslo_utils import uuidutils
 import paramiko
-import six
 from webob import exc
 
 import manila
@@ -75,24 +73,6 @@ class GenericUtilsTestCase(test.TestCase):
             self.assertFalse(result)
             timeutils.utcnow.assert_called_once_with()
 
-    def test_is_eventlet_bug105(self):
-        fake_dns = mock.Mock()
-        fake_dns.getaddrinfo.side_effect = socket.gaierror(errno.EBADF)
-        with mock.patch.dict('sys.modules', {
-                'eventlet.support.greendns': fake_dns}):
-            self.assertTrue(utils.is_eventlet_bug105())
-            self.assertTrue(fake_dns.getaddrinfo.called)
-
-    def test_is_eventlet_bug105_neg(self):
-        fake_dns = mock.Mock()
-        fake_dns.getaddrinfo.return_value = [
-            (socket.AF_INET6, socket.SOCK_STREAM, 0, '', (u'127.0.0.1', 80)),
-        ]
-        with mock.patch.dict('sys.modules', {
-                'eventlet.support.greendns': fake_dns}):
-            self.assertFalse(utils.is_eventlet_bug105())
-            fake_dns.getaddrinfo.assert_called_once_with('::1', 80)
-
     @ddt.data(['ssh', '-D', 'my_name@name_of_remote_computer'],
               ['echo', '"quoted arg with space"'],
               ['echo', "'quoted arg with space'"])
@@ -345,6 +325,40 @@ class SSHPoolTestCase(test.TestCase):
             self.assertNotEqual(first_id, third_id)
             paramiko.SSHClient.assert_called_once_with()
 
+    @mock.patch('builtins.open')
+    @mock.patch('paramiko.SSHClient')
+    @mock.patch('os.path.isfile', return_value=True)
+    def test_sshpool_remove(self, mock_isfile, mock_sshclient, mock_open):
+        ssh_to_remove = mock.Mock()
+        mock_sshclient.side_effect = [mock.Mock(), ssh_to_remove, mock.Mock()]
+        sshpool = utils.SSHPool("127.0.0.1", 22, 10, "test", password="test",
+                                min_size=3, max_size=3)
+
+        self.assertIn(ssh_to_remove, list(sshpool.free_items))
+
+        sshpool.remove(ssh_to_remove)
+
+        self.assertNotIn(ssh_to_remove, list(sshpool.free_items))
+
+    @mock.patch('builtins.open')
+    @mock.patch('paramiko.SSHClient')
+    @mock.patch('os.path.isfile', return_value=True)
+    def test_sshpool_remove_object_not_in_pool(self, mock_isfile,
+                                               mock_sshclient, mock_open):
+        # create an SSH Client that is not a part of sshpool.
+        ssh_to_remove = mock.Mock()
+        mock_sshclient.side_effect = [mock.Mock(), mock.Mock()]
+
+        sshpool = utils.SSHPool("127.0.0.1", 22, 10, "test", password="test",
+                                min_size=2, max_size=2)
+        listBefore = list(sshpool.free_items)
+
+        self.assertNotIn(ssh_to_remove, listBefore)
+
+        sshpool.remove(ssh_to_remove)
+
+        self.assertEqual(listBefore, list(sshpool.free_items))
+
 
 @ddt.ddt
 class CidrToNetmaskTestCase(test.TestCase):
@@ -790,36 +804,23 @@ class ShareMigrationHelperTestCase(test.TestCase):
 class ConvertStrTestCase(test.TestCase):
 
     def test_convert_str_str_input(self):
-        self.mock_object(utils.encodeutils, 'safe_encode')
-        input_value = six.text_type("string_input")
+        self.mock_object(encodeutils, 'safe_encode')
+        input_value = "string_input"
 
         output_value = utils.convert_str(input_value)
 
-        if six.PY2:
-            utils.encodeutils.safe_encode.assert_called_once_with(input_value)
-            self.assertEqual(
-                utils.encodeutils.safe_encode.return_value, output_value)
-        else:
-            self.assertEqual(0, utils.encodeutils.safe_encode.call_count)
-            self.assertEqual(input_value, output_value)
+        self.assertEqual(0, encodeutils.safe_encode.call_count)
+        self.assertEqual(input_value, output_value)
 
     def test_convert_str_bytes_input(self):
-        self.mock_object(utils.encodeutils, 'safe_encode')
-        if six.PY2:
-            input_value = six.binary_type("binary_input")
-        else:
-            input_value = six.binary_type("binary_input", "utf-8")
+        self.mock_object(encodeutils, 'safe_encode')
+        input_value = bytes("binary_input", "utf-8")
 
         output_value = utils.convert_str(input_value)
 
-        if six.PY2:
-            utils.encodeutils.safe_encode.assert_called_once_with(input_value)
-            self.assertEqual(
-                utils.encodeutils.safe_encode.return_value, output_value)
-        else:
-            self.assertEqual(0, utils.encodeutils.safe_encode.call_count)
-            self.assertIsInstance(output_value, six.string_types)
-            self.assertEqual(six.text_type("binary_input"), output_value)
+        self.assertEqual(0, encodeutils.safe_encode.call_count)
+        self.assertIsInstance(output_value, str)
+        self.assertEqual(str("binary_input"), output_value)
 
 
 @ddt.ddt
